@@ -18,6 +18,7 @@ import sys
 import os
 import subprocess
 import wx
+from threading import Thread
 from wx.lib.dialogs import messageDialog as message
 from M30W.debug import debug, print_not_implemented_functions
 from errorConsole import ErrorConsole
@@ -27,30 +28,33 @@ from M30W import media, runtime, IO
 from M30W.config import config
 
 
+NORMAL = 'normal'
 SEPARATOR = 'separator'
-SUBMENU = 'submenu'
+CHECK = 'checkitem'
 
 
 class Menu(wx.Menu):
     def __init__(self, parent, items, *args, **kwargs):
         wx.Menu.__init__(self, *args, **kwargs)
         self.parent = parent
-        for item, itemid, callback in items:
-            if itemid == SEPARATOR:
+        for data in items:
+            if data[0] == SEPARATOR:
                 self.AppendSeparator()
-            elif itemid == SUBMENU:
-                self.AppendSubMenu()
+            elif data[0] == CHECK:
+                # (TYPE, title, ID, callback, activated)
+                item = self.AppendCheckItem(data[2], data[1])
+                self.Check(data[2], data[4])
+                self.parent.Bind(wx.EVT_MENU, data[3], item)
             else:
-                item = self.Append(itemid, item)
-                self.parent.Bind(wx.EVT_MENU, callback, item)
+                # (TYPE, title, ID, callback)
+                item = self.Append(data[2], data[1])
+                self.parent.Bind(wx.EVT_MENU, data[3], item)
 
 
 class MenuBar(wx.MenuBar):
     def __init__(self, parent, menus, *args, **kwargs):
         wx.MenuBar.__init__(self, *args, **kwargs)
         self.parent = parent
-        global menubar
-        menubar = self
         for title, items in menus:
             self.Append(Menu(self.parent, items), title)
 
@@ -134,6 +138,25 @@ def OnReload(e):
     if not runtime.project.path: return
     IO.reload()
 
+thread = None
+
+def OnStart(e):
+    global thread
+    if thread and thread.is_alive():
+        runtime.engine.trigger(runtime.engine.GREENFLAG_EVENT)
+    else:
+        runtime.engine.clear_bindings()
+        runtime.project.compile_scripts()
+        #thread = Thread(target=runtime.engine.start)
+        #thread.start()
+        runtime.engine.start()
+
+def OnStop(e):
+    runtime.engine.stop()
+
+def OnShowStage(event):
+    runtime.rightPanel.ShowStage(event.IsChecked())
+
 def OnPreferences(event):
     PreferencesDialog(runtime.mainFrame)
 
@@ -173,19 +196,32 @@ def OnPrint(event):
     print_not_implemented_functions()
 
 
-File = (('&New\tCtrl+N', wx.ID_NEW, OnNew),
-        ('&Open\tCtrl+O', wx.ID_OPEN, OnOpen),
-        (None, SEPARATOR, None),
-        ('&Save\tCtrl+S', wx.ID_SAVE, OnSave),
-        ('Save &As\tCtrl+Shift+S', wx.ID_SAVEAS, OnSaveAs),
-        (None, SEPARATOR, None),
-        ('&Quit', wx.ID_EXIT, OnQuit))
-Edit = (('Save And Open In Scratch', wx.ID_ANY, OnSaveAndOpenInScratch),
-        ('Reload', wx.ID_ANY, OnReload),
-        (None, SEPARATOR, None),
-        ("&Preferences", wx.ID_PREFERENCES, OnPreferences))
-Help = [('Error Console', wx.ID_ANY, OnConsole),
-        ('Print Not Implemented Functions', wx.ID_ANY, OnPrint),
-        (None, SEPARATOR, None),
-        ('About M30W', wx.ID_ABOUT, OnAbout)]
+#===============================================================================
+# Different kinds of menu items:
+# (NORMAL, '&Title\tCtrl+X', ID, callback)
+# (SEPARATOR, )
+# (CHECK, 'Title\tCtrl+X', ID, callback, activated)
+#===============================================================================
+
+File = ((NORMAL, '&New\tCtrl+N', wx.ID_NEW, OnNew),
+        (NORMAL, '&Open\tCtrl+O', wx.ID_OPEN, OnOpen),
+        (SEPARATOR,),
+        (NORMAL, '&Save\tCtrl+S', wx.ID_SAVE, OnSave),
+        (NORMAL, 'Save &As\tCtrl+Shift+S', wx.ID_SAVEAS, OnSaveAs),
+        (SEPARATOR,),
+        (NORMAL, '&Quit', wx.ID_EXIT, OnQuit))
+Edit = ((NORMAL, 'Save And Open In Scratch', wx.ID_ANY, OnSaveAndOpenInScratch),
+        (NORMAL, 'Reload', wx.ID_ANY, OnReload),
+        (SEPARATOR,),
+        (NORMAL, 'Start Scripts', wx.ID_ANY, OnStart),
+        (NORMAL, 'Stop Scripts', wx.ID_ANY, OnStop),
+        (SEPARATOR,),
+        (CHECK, 'Show Stage', wx.ID_PAGE_SETUP, OnShowStage, True),
+        (SEPARATOR,),
+        (NORMAL, "&Preferences", wx.ID_PREFERENCES, OnPreferences))
+Help = [(NORMAL, 'Error Console', wx.ID_ANY, OnConsole),
+        (NORMAL, 'Print Not Implemented Functions', wx.ID_ANY, OnPrint),
+        (SEPARATOR,),
+        (NORMAL, 'About M30W', wx.ID_ABOUT, OnAbout)]
+
 menus = (('&File', File), ('&Edit', Edit), ('&Help', Help))
