@@ -17,7 +17,9 @@
 """
 Project class - stores sprites, project infos etc.
 """
+
 import cPickle as pickle
+import gc
 from hashlib import sha256
 from M30W import sprites
 from M30W.debug import debug, not_implemented, ensure_kurt
@@ -46,16 +48,26 @@ class Project(object):
         self.last_save = sha256(pickle.dumps(self, protocol=2)).hexdigest()
 
     def __getstate__(self):
-        dict = self.__dict__.copy()
-        dict.pop('last_save', None)
-        return dict
+        state = self.__dict__.copy()
+        state.pop('last_save', None)
+        return state
 
-    def __setstate__(self, dict):
-        self.__dict__ = dict
+    def __setstate__(self, state):
+        self.__dict__ = state
         self.last_save = sha256(pickle.dumps(self, protocol=2)).hexdigest()
 
+    def __getitem__(self, key):
+        return {name: sprite for name, sprite in
+                zip(map(lambda s: s.name, self.sprites + [self.stage]),
+                    self.sprites + [self.stage])}[key]
+
     @classmethod
     def from_kurt(cls, morph):
+        """from_kurt(cls, morph)
+        
+        `morph` is a kurt.ScratchProjectFile object
+        """
+
         stage = sprites.Stage.from_kurt(morph.stage)
         #Redefining sprites from outer scope...
         
@@ -123,8 +135,17 @@ class Project(object):
             ensure_kurt()
             project = kurt.ScratchProjectFile(self.path)
             self.__dict__ = Project.from_kurt(project).__dict__
+            del project; gc.collect()  # kurt uses circular hardrefs O.o
         debug("Done.", -1)
 
+    def compile_scripts(self):
+        """Make every sprite compile its scripts and bind them to events.
+        
+        TODO: Cache compiled scripts.
+        """
+        self.stage.compile_scripts()
+        map(sprites.Sprite.compile_scripts, self.sprites)
+
     def new_sprite_from(self, path):
         ensure_kurt()
         file = kurt.ScratchSpriteFile(path)
