@@ -14,6 +14,8 @@
 #You should have received a copy of the GNU General Public License
 #along with this program. If not, see <http://www.gnu.org/licenses/>.
 
+from math import cos, sin, radians, pi
+import time
 from .base import Base
 from M30W.costume import Costume, get_default_costume
 from M30W.lists import ScratchList
@@ -39,6 +41,13 @@ class Sprite(Base):
                    'size': lambda: 100.0,
                    'visible': lambda: True})
 
+    blocks = Base.blocks.copy()
+    def block(name, blocks=blocks):
+        def decorator(method):
+            method.func_name = name
+            blocks[name] = method
+        return decorator       
+
     def __init__(self, name, **kwargs):
         super(Sprite, self).__init__(name, **kwargs)
 
@@ -204,3 +213,112 @@ class Sprite(Base):
     def visible(self, value):
         self._visible = bool(value)
         self.redraw()
+
+    #==========================================================================
+    # Begin blocks code
+    #==========================================================================
+
+    ### Motion Blocks ###
+
+    @block('forward:')
+    def _(self, steps):
+        steps = self.number(steps)
+        direction = radians(self.direction) + pi / 2
+        dx, dy = (cos(direction) * steps), (sin(direction) * steps)
+        print dx, dy
+        self.x += dx
+        self.y += dy
+
+    @block('turnRight:')
+    def _(self, degrees):
+        self.direction += self.number(degrees)
+
+    @block('turnLeft:')
+    def _(self, degrees):
+        self.direction -= self.number(degrees)
+    ###
+    @block('heading:')
+    def _(self, direction):
+        self.direction = self.number(direction)
+
+    @block('pointTowards:')
+    @not_implemented
+    def _(self, target):
+        pass
+    ###
+    @block('gotoX:y:')
+    def _(self, x, y):
+        self.x = self.number(x)
+        self.y = self.number(y)
+
+    @block('gotoSpriteOrMouse:')
+    @not_implemented
+    def _(self):
+        pass
+
+    @block('glideSecs:toX:y:elapsed:from:')
+    @not_implemented
+    def _(self, time, x, y):
+        pass
+    ###
+
+    @block('changeXposBy:')
+    def _(self, x):
+        self.x += self.number(x)
+
+    @block('xpos:')
+    def _(self, x):
+        self.x = self.number(x)
+
+    @block('changeYposBy:')
+    def _(self, y):
+        self.y += self.number(y)
+
+    @block('ypos:')
+    def _(self, y):
+        self.y = self.number(y)
+    ###
+    @block('bounceOffEdge')
+    @not_implemented
+    def _(self):
+        pass
+    ###
+    block('xpos')(lambda self: self.x)
+    block('ypos')(lambda self: self.y)
+    block('heading')(lambda self: self.direction)
+
+    ### Looks Blocks ###
+
+    @block('say:duration:elapsed:from:')
+    def _(self, message, duration):
+        print self.string(message)
+        exec_time = time.time()
+        while not exec_time - time.time() > self.number(duration):
+            yield 
+
+    block('think:duration:elapsed:from:')(blocks['say:duration:elapsed:from:'])
+
+    @block('say:')
+    def _(self, message):
+        print self.string(message)
+
+    block('think:')(blocks['say:'])
+    #TODO: When we get to speech/thinking bubbles, write different methods
+
+    @block('changeSizeBy:')
+    def _(self, size):
+        self.size += self.number(size)
+
+    @block('setSizeTo:')
+    def _(self, size):
+        self.size = self.number(size)
+
+    block('scale')(lambda self: self.size)
+
+    @block('show')
+    def _(self):
+        self.visible = True
+
+    @block('hide')
+    def _(self):
+        self.visible = False
