@@ -27,6 +27,13 @@ class Stage(Base):
     kwords = Base.kwords.copy()
     kwords.update({'tempo': lambda: 60})
 
+    blocks = Base.blocks.copy()
+    def block(name, blocks=blocks):
+        def decorator(method):
+            method.func_name = name
+            blocks[name] = method
+        return decorator
+
     def __init__(self, **kwargs):
         """Stage(self, costumes=[], costume=0, code="", vars={}, lists={},
                 volume=100, tempo=60)
